@@ -1,3 +1,4 @@
+import json
 import time
 
 import requests
@@ -32,12 +33,20 @@ def get_req_resp_record(resp_obj: Response) -> ReqRespData:
     def log_print(req_or_resp, r_type):
         msg = f"\n================== {r_type} details ==================\n"
         for key, value in req_or_resp.dict().items():
-            msg += "{:<16} : {}\n".format(key, repr(value))
+            if isinstance(value, dict):
+                value = json.dumps(value, indent=4)
+
+            msg += "{:<8} : {}\n".format(key, value)
         logger.debug(msg)
 
     # record actual request info
     request_headers = dict(resp_obj.request.headers)
+    request_cookies = dict(resp_obj.request._cookies)
     request_body = resp_obj.request.body
+    try:
+        request_body = json.loads(request_body)
+    except json.JSONDecodeError:
+        pass
 
     if request_body:
         request_content_type = lower_dict_keys(request_headers).get("content-type")
@@ -49,6 +58,7 @@ def get_req_resp_record(resp_obj: Response) -> ReqRespData:
         method=resp_obj.request.method,
         url=resp_obj.request.url,
         headers=request_headers,
+        cookies=request_cookies,
         body=request_body,
     )
 
@@ -184,7 +194,7 @@ class HttpSession(requests.Session):
             logger.info(
                 f"status_code: {response.status_code}, "
                 f"response_time(ms): {response_time_ms} ms, "
-                f"response_length: {content_size} bytes\n"
+                f"response_length: {content_size} bytes"
             )
 
         return response
@@ -195,10 +205,6 @@ class HttpSession(requests.Session):
         Safe mode has been removed from requests 1.x.
         """
         try:
-            msg = "processed request:\n"
-            msg += f"> {method} {url}\n"
-            msg += f"> kwargs: {kwargs}"
-            logger.debug(msg)
             return requests.Session.request(self, method, url, **kwargs)
         except (MissingSchema, InvalidSchema, InvalidURL):
             raise
