@@ -14,24 +14,6 @@ except ImportError:
     JSONDecodeError = ValueError
 
 
-IGNORE_REQUEST_HEADERS = [
-    "host",
-    "accept",
-    "content-length",
-    "connection",
-    "accept-encoding",
-    "accept-language",
-    "origin",
-    "cache-control",
-    "pragma",
-    "upgrade-insecure-requests",
-    ":authority",
-    ":method",
-    ":scheme",
-    ":path",
-]
-
-
 class HarParser(object):
     def __init__(self, har_file_path, filter_str=None, exclude_str=None):
         self.har_file_path = har_file_path
@@ -93,6 +75,14 @@ class HarParser(object):
 
         teststep_dict["request"]["method"] = method
 
+    def __make_request_cookies(self, teststep_dict, entry_json):
+        cookies = {}
+        for cookie in entry_json["request"].get("cookies", []):
+            cookies[cookie["name"]] = cookie["value"]
+
+        if cookies:
+            teststep_dict["request"]["cookies"] = cookies
+
     def __make_request_headers(self, teststep_dict, entry_json):
         """ parse HAR entry request headers, and make teststep headers.
             header in IGNORE_REQUEST_HEADERS will be ignored.
@@ -119,7 +109,7 @@ class HarParser(object):
         """
         teststep_headers = {}
         for header in entry_json["request"].get("headers", []):
-            if header["name"].lower() in IGNORE_REQUEST_HEADERS:
+            if header["name"] == "cookie" or header["name"].startswith(":"):
                 continue
 
             teststep_headers[header["name"]] = header["value"]
@@ -288,6 +278,7 @@ class HarParser(object):
 
         self.__make_request_url(teststep_dict, entry_json)
         self.__make_request_method(teststep_dict, entry_json)
+        self.__make_request_cookies(teststep_dict, entry_json)
         self.__make_request_headers(teststep_dict, entry_json)
         self._make_request_data(teststep_dict, entry_json)
         self._make_validate(teststep_dict, entry_json)
