@@ -124,6 +124,7 @@ class ResponseObject(object):
         self.resp_obj_meta = {
             "status_code": resp_obj.status_code,
             "headers": resp_obj.headers,
+            "cookies": dict(resp_obj.cookies),
             "body": body,
         }
         self.validation_results: Dict = {}
@@ -163,6 +164,8 @@ class ResponseObject(object):
 
             # check item
             check_item = u_validator["check"]
+            # TODO: validate variable or function
+            # check_item = parse_data(check_item, variables_mapping, functions_mapping)
             check_value = jmespath.search(check_item, self.resp_obj_meta)
             check_value = parse_string_value(check_value)
 
